# -*- coding: utf-8 -*-
"""
Created on Mon Sep 16 16:26:54 2019

@author: msardar2
"""
from .InputData import InputData
from .CommonData import CommonData
from pathlib import Path
import pandas as pd
import ast


class LF_Input(InputData):
    def __init__(self, input_data_path=None, process_data_path=None,
                 process_name='LF', CommonDataObjct=None):
        if input_data_path:
            self.input_data_path = input_data_path
        else:
            self.input_data_path = Path(__file__).parent / 'Data/LF_Input.csv'

        # Initialize the superclass
        super().__init__(self.input_data_path, process_name)

        if not CommonDataObjct:
            CommonDataObjct = CommonData()

        if process_data_path is None:
            process_data_path = Path(__file__).parent / "Data/LF_Input_MaterialDependent.csv"
        self.add_process_data(process_data_path=process_data_path,
                              index=CommonDataObjct.Index)

        self.gas_emission_factor = pd.read_csv(Path(__file__).parent / 'Data/LF_Gas_emission_factors.csv',
                                               converters={'Biosphere_key': ast.literal_eval})
        self.gas_emission_factor.fillna('', inplace=True)

        self.lcht_Qlty = pd.read_csv(Path(__file__).parent / 'Data/LF_Leachate_Quality.csv',
                                     converters={'Surface_water': ast.literal_eval, 'Ground_water': ast.literal_eval})
        self.lcht_Qlty.fillna(0, inplace=True)

        self.GasColPlan = pd.read_csv(Path(__file__).parent / 'Data/LF_GasColPlan.csv', index_col=0)



# -*- coding: utf-8 -*-
"""
Created on Fri May  8 00:12:49 2020

@author: msmsa
"""
import swolfpy_inputdata as si


def test_all_inputs():
    A = si.LF_Input()
    A.setup_MC()
    assert isinstance(A.gen_MC(), list)

    assert si.WTE_Input()

    assert si.Comp_Input()

    assert si.AD_Input()

    assert si.SS_MRF_Input()

    assert si.Reproc_Input()

    assert si.SF_Col_Input()

    assert si.Technosphere_Input()

    assert si.CommonData()

    assert si.GC_Input()

    assert si.RDF_Input()

    assert si.HC_Input()

    assert si.TS_Input()



# -*- coding: utf-8 -*-
"""
Created on Fri Nov 22 11:16:05 2019

@author: msardar2
"""
from pathlib import Path
import pandas as pd


class Technosphere_Input():
    def __init__(self, LCI_path=None, LCI_Reference_path=None, Ecospold2_Path=None):

        # Checking the path for technosphere LCI data and writing the technophere database
        if LCI_path:
            self.technosphere_path = LCI_path
        else:
            self.technosphere_path = Path(__file__).parent / 'Data/Technosphere_LCI.csv'

        # Checking the path for technosphere LCI references
        if LCI_Reference_path:
            self.LCI_Reference_path = LCI_Reference_path
        else:
            self.LCI_Reference_path = Path(__file__).parent / 'Data/Technosphere_References.csv'

        # Checking the path for Ecospold2
        if Ecospold2_Path:
            self.Ecospold2_Path = Ecospold2_Path
        else:
            self.Ecospold2_Path = Path(__file__).parent / 'Data/Ecospold2'

        # Read the data
        self.LCI_swolfpy_data = pd.read_csv(self.technosphere_path)
        self.LCI_reference = pd.read_csv(self.LCI_Reference_path, index_col='swolfpy_technosphere_name')

        if self.LCI_reference['Reference_activity_id'].count() > 0 and self.Ecospold2_Path is None:
            raise ValueError('User should select the path to ecospold files, because of keys in Technosphere_References.csv')



# -*- coding: utf-8 -*-
"""
Created on Tue Apr 21 20:45:14 2020

@author: msmsa
"""
import pandas as pd
from .MC import MC
import ast


class InputData(MC):
    """
    ``InputData`` class reads the input data from the csv file and load them as class attributes. This class is inherited from the ``MC`` class.

    Main functionalities include:
    loading data, updating data and generating random number for data based on the defined probabiliy distributions.

    :param input_data_path: absolute path to the input data file
    :type input_data_path: str
    :param eval_parameter: If the parameters are tuple instead of str, it will evalute their real value.
    :type eval_parameter: bool, optional

    """
    def __init__(self, input_data_path, process_name, eval_parameter=False):
        """Initialize ``InputData`` class
        """
        self.input_data_path = input_data_path
        self.process_name = process_name
        self.Data = pd.read_csv(self.input_data_path, dtype={'amount': float, 'uncertainty_type': float, 'loc': float,
                                                             'scale': float, 'shape': float, 'minimum': float, 'maximum': float})

        if eval_parameter:
            self.Data['Parameter Name'] = self.Data['Parameter Name'].apply(ast.literal_eval)

        # Setting uncertainty type to 0 : Undefined ; when it is not defined
        self.Data['uncertainty_type'].fillna(0, inplace=True)
        # self.Data=self.Data.where((pd.notnull(self.Data)), None)
        self.Input_dict = {}
        self.keys = self.Data.columns[3:]
        for i in range(len(self.Data)):
            if self.Data.Category[i] not in self.Input_dict.keys():
                exec("self.%s = {}" % self.Data.Dictonary_Name[i])
                exec("self.Input_dict[self.Data.Category[i]] = self.%s" % self.Data.Dictonary_Name[i])
                exec("self.%s[self.Data['Parameter Name'][i]] = dict(zip(self.keys,self.Data.loc[i,'Parameter Description':]))" %
                     self.Data.Dictonary_Name[i])
            else:
                exec("self.%s[self.Data['Parameter Name'][i]] = dict(zip(self.keys,self.Data.loc[i,'Parameter Description':]))" %
                     self.Data.Dictonary_Name[i])

### Add process data
    def add_process_data(self, process_data_path, index):
        self.process_data = pd.read_csv(process_data_path,
                                        index_col=0,
                                        header=0,
                                        skiprows=[1, 2, 3]).loc[index].astype(float)
        self.process_data.fillna(0, inplace=True)
        self.process_data_info = pd.read_csv(process_data_path,
                                             index_col=0,
                                             header=0,
                                             nrows=3)

### Update_Input
    def Update_input(self, NewData):
        """ Get a new DataFrame and update the ``data`` in ``InputData`` class.

        :param NewData:
        :type NewData: 'pandas.DataFrame'
        """
        for i in NewData.index:
            exec("self.%s[NewData['Parameter Name'][i]] = dict(zip(self.keys,NewData.loc[i,'Parameter Description':]))" % NewData.Dictonary_Name[i])
            self.Data.loc[i] = NewData.loc[i]

### Monte_carlo
    def setup_MC(self, seed=None):
        """ Initialize the parent class (``MC``) and create ``MCRandomNumberGenerator`` based on the data for uncertainty distributions via
        calling ``MC.setupMC()`` method.

        :param seed: seed for random number generation
        :type seed: int, optional

        .. seealso:: Class_MC_
        """
        super().__init__(self.Input_dict, self.process_name)
        super().setup_MC(seed)

### Reset static Values
    def reset_static_vals(self):
        for i in self.Data.index:
            exec("self.%s[self.Data['Parameter Name'][i]]['amount'] = self.Data.loc[i,'amount']" % self.Data.Dictonary_Name[i])



#!/usr/bin/env python

"""Tests for `swolfpy_inputdata` package."""

import pytest
from swolfpy_inputdata import InputData
from copy import deepcopy
from pathlib import Path


@pytest.fixture(scope="module")
def Input_Data():
    A = InputData(Path(__file__).parent / 'Test_Input.csv', process_name='test')
    yield A


def test_InputData(Input_Data):
    assert list(Input_Data.Data.columns) == ['Category', 'Dictonary_Name', 'Parameter Name', 'Parameter Description', 'amount', 'unit',
                                             'uncertainty_type', 'loc', 'scale', 'shape', 'minimum', 'maximum',
                                             'Reference', 'Comment']
    assert Input_Data.Dic1
    assert Input_Data.Dic2
    assert Input_Data.Dic1['Par1']['Parameter Description'] == 'Name1'
    assert Input_Data.Dic1['Par1']['amount'] == 1
    assert Input_Data.Dic1['Par1']['uncertainty_type'] == 0


def test_update_InputData(Input_Data):
    newdata = deepcopy(Input_Data.Data)
    # add uncertainty to Par2 of Dic1
    newdata.loc[1, 'amount'] = 3
    newdata.loc[1, 'uncertainty_type'] = 3
    newdata.loc[1, 'loc'] = 3
    newdata.loc[1, 'scale'] = 0.5

    Input_Data.Update_input(newdata)
    assert Input_Data.Dic1['Par2']['uncertainty_type'] == 3
    assert Input_Data.Dic1['Par2']['amount'] == 3
    assert Input_Data.Dic1['Par2']['loc'] == 3
    assert Input_Data.Dic1['Par2']['scale'] == 0.5


def test_setup_MC(Input_Data):
    Input_Data.setup_MC()
    assert Input_Data.Dic1['Par2']['amount'] == 3
    assert isinstance(Input_Data.gen_MC(), list)
    assert isinstance(Input_Data.gen_MC()[0], tuple)
    assert Input_Data.gen_MC()[0][0] == ('test', 'Cat1', 'Par2')
    assert abs(Input_Data.gen_MC()[0][1] - 3) <= 2



# -*- coding: utf-8 -*-
"""
@author: Mojtaba Sardarmehni

Input data for the swolfpy's life_cycle process models
"""
from .MC import MC
from .InputData import InputData
from .CommonData import CommonData
from .Technosphere_Input import Technosphere_Input
from .LF_Input import LF_Input
from .WTE_Input import WTE_Input
from .Comp_Input import Comp_Input
from .AD_Input import AD_Input
from .SS_MRF_Input import SS_MRF_Input
from .Reproc_Input import Reproc_Input
from .SF_Col_Input import SF_Col_Input
from .TS_Input import TS_Input
from .HC_Input import HC_Input
from .GC_Input import GC_Input
from .RDF_Input import RDF_Input

__all__ = [
    'MC',
    'InputData',
    'CommonData',
    'Technosphere_Input',
    'LF_Input',
    'WTE_Input',
    'Comp_Input',
    'AD_Input',
    'SS_MRF_Input',
    'Reproc_Input',
    'SF_Col_Input',
    'TS_Input',
    'HC_Input',
    'GC_Input',
    'RDF_Input',
]

__version__ = '0.2.3'



# -*- coding: utf-8 -*-
"""
Created on Tue Jan  7 11:11:58 2020

@author: msardar2
"""
from .InputData import InputData
from .CommonData import CommonData
from pathlib import Path


class TS_Input(InputData):
    def __init__(self, input_data_path=None, process_name='TS', CommonDataObjct=None):
        if input_data_path:
            self.input_data_path = input_data_path
        else:
            self.input_data_path = Path(__file__).parent / 'Data/TS_Input.csv'

        # Initialize the superclass
        super().__init__(self.input_data_path, process_name)

        if not CommonDataObjct:
            CommonDataObjct = CommonData()



# -*- coding: utf-8 -*-
"""
Created on Mon Jul  1 20:05:32 2019

@author: msardar2
"""
from .InputData import InputData
from pathlib import Path
import pandas as pd


class CommonData(InputData):
    # Recycling products index
    Reprocessing_Index = ['Al', 'Fe',
                          'OCC', 'Mixed_Paper', 'ONP', 'OFF', 'Fiber_Other',
                          'Brown_glass', 'Clear_glass', 'Green_glass', 'Mixed_Glass',
                          'PET', 'HDPE_P', 'HDPE_T', 'LDPE_Film']

    # Collection products index
    Collection_Index = ['RWC', 'SSR', 'DSR', 'MSR', 'LV', 'SSYW', 'SSO',
                        'SSO_HC', 'ORG', 'DryRes', 'REC', 'WetRes',
                        'MRDO', 'SSYWDO', 'MSRDO']

    # Waste products index
    Waste_Pr_Index = ['Bottom_Ash', 'Fly_Ash', 'Unreacted_Ash', 'Separated_Organics',
                      'Other_Residual', 'Separated_Recyclables', 'RDF']

    # all waste_pr_index
    All_Waste_Pr_Index = (Waste_Pr_Index
                          + Collection_Index
                          + Reprocessing_Index)

    # Materials
    Index = ['Yard_Trimmings_Leaves', 'Yard_Trimmings_Grass', 'Yard_Trimmings_Branches', 'Food_Waste_Vegetable',
             'Food_Waste_Non_Vegetable', 'Wood', 'Wood_Other', 'Textiles', 'Rubber_Leather', 'Newsprint',
             'Corr_Cardboard', 'Office_Paper', 'Magazines', 'Third_Class_Mail', 'Folding_Containers', 'Paper_Bags',
             'Mixed_Paper', 'Paper_Non_recyclable', 'HDPE_Translucent_Containers', 'HDPE_Pigmented_Containers',
             'PET_Containers', 'Plastic_Other_1_Polypropylene', 'Plastic_Other_2', 'Mixed_Plastic', 'Plastic_Film',
             'Plastic_Non_Recyclable', 'Ferrous_Cans', 'Ferrous_Metal_Other', 'Aluminum_Cans', 'Aluminum_Foil',
             'Aluminum_Other', 'Ferrous_Non_recyclable', 'Al_Non_recyclable', 'Glass_Brown', 'Glass_Green',
             'Glass_Clear', 'Mixed_Glass', 'Glass_Non_recyclable', 'Misc_Organic', 'Misc_Inorganic', 'E_waste',
             'Bottom_Ash', 'Fly_Ash', 'Diapers_and_sanitary_products']

    def __init__(self, input_data_path=None, process_name='CommonData'):
        if input_data_path:
            self.input_data_path = input_data_path
        else:
            self.input_data_path = Path(__file__).parent / 'Data/CommonData.csv'

        # Initialize the superclass
        super().__init__(self.input_data_path, process_name)

        ### Read Material properties
        self.Material_Properties = pd.read_csv(Path(__file__).parent / "Data/Material properties.csv",
                                               index_col=0,
                                               header=0,
                                               skiprows=[1, 2, 3]).loc[self.Index].astype(float)
        self.Material_Properties.fillna(0, inplace=True)
        self.Material_Properties_Info = pd.read_csv(Path(__file__).parent / "Data/Material properties.csv",
                                                    index_col=0,
                                                    header=0,
                                                    nrows=3)



#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
'pandas',
'xlrd==1.2.0',
'stats-arrays',
'jupyter',
"pytest",
"pytest-cov",
"pytest-flake8",
"coverage",
]

setup_requirements = [ ]

package_input_data = {'swolfpy_inputdata.Data':['*.csv'],
                      'swolfpy_inputdata.Data.LCIA_Methods':['*.csv']}
                                                                

test_requirements = [ ]

files = None


setup(
    author="Mojtaba Sardarmehni",
    author_email='msardar2@ncsu.edu',
    python_requires='>=3.7',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Education',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: GNU General Public License v2 (GPLv2)',
        'Natural Language :: English',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Microsoft :: Windows',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Scientific/Engineering :: Mathematics',
        'Topic :: Scientific/Engineering :: Visualization',
        'Natural Language :: English',
    ],
    description="Input data for swolfpy's life-cycle process models (swolfpy_inputdata)",
    install_requires=requirements,
    license="GNU GENERAL PUBLIC LICENSE V2",
    long_description=readme + '\n\n' + history,
    long_description_content_type= 'text/x-rst',
    include_package_data=True,
    keywords='swolfpy_inputdata',
    name='swolfpy_inputdata',
    packages=find_packages(include=['swolfpy_inputdata', 'swolfpy_inputdata.*']),
    setup_requires=setup_requirements,
    package_data=package_input_data,
    data_files = files,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/SwolfPy-Project/swolfpy-inputdata',
    version='0.2.3',
    zip_safe=False,
)



# -*- coding: utf-8 -*-
"""
Created on Mon Oct 21 22:52:32 2019

@author: msmsa
"""
from .InputData import InputData
from .CommonData import CommonData
from pathlib import Path
import pandas as pd


class SF_Col_Input(InputData):
    def __init__(self, input_data_path=None, process_data_path=None,
                 process_name='SF_Col', CommonDataObjct=None):
        if input_data_path:
            self.input_data_path = input_data_path
        else:
            self.input_data_path = Path(__file__).parent / 'Data/SF_Col_Input.csv'

        # Initialize the superclass
        super().__init__(self.input_data_path, process_name)

        if not CommonDataObjct:
            CommonDataObjct = CommonData()

        if process_data_path is None:
            process_data_path = Path(__file__).parent / "Data/SF_Col_Input_MaterialDependent.csv"
        self.add_process_data(process_data_path=process_data_path,
                              index=CommonDataObjct.Index)

        ### Read input data
        self.col = pd.read_csv(Path(__file__).parent / 'Data/SF_Col_Input_process.csv',
                               index_col='Name',
                               usecols=['Name', 'RWC', 'SSR', 'DSR', 'MSR', 'LV', 'SSYW', 'SSO', 'ORG', 'DryRes', 'REC',
                                        'WetRes', 'MRDO', 'SSYWDO', 'MSRDO']).astype(float)
        self.col = self.col.transpose()
